@@ -120,4 +120,4 @@ def process(function: FunctionType):
     """
     Create a process worker. This function will run your function in a separate GIL
     """
-    return ProcessConnector(function)
\ No newline at end of file
+    return ProcessConnector.create_process(function)
\ No newline at end of file
